@@ -23,6 +23,7 @@ def data_preprocessing(
     for_future_test=False,
     verbose=1,
     save_results=True,
+    root_path=None,
 ):
     """A simple automate data preprocessing step
 
@@ -45,6 +46,7 @@ def data_preprocessing(
             Defaults to 1. 1: show information; 0: not show information.
         save_results (bool, optional): whether to save the parameters, which
             will be useful to preprocess new data sets. Defaults to True.
+        root_path (str, optional): the parent folder to save results.
 
     Raises:
         NameError: The outcome is not found in the data.
@@ -156,8 +158,15 @@ def data_preprocessing(
 
     # check the document of np.savez_compressed to see how to load the saved data
     if save_results:
-        # path to the report
-        target_path = os.path.join("./results", name)
+        # target_path
+        if root_path is None:
+            target_path = os.path.join("./results", name)
+        else:
+            target_path = os.path.join(root_path, name)
+        if not os.path.isdir(target_path):
+            os.mkdir(target_path)
+
+        # path to the preprocessed data
         path2data = os.path.join(target_path, "data.npz")
         np.savez_compressed(
             path2data,
